==> flexible-process-springboot-1.4.0.Final-sources.jar: org/kie/flexible/kogito/example/ServiceDesk_11_TaskInput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.flexible.kogito.example;

import java.util.Map;
import org.kie.kogito.UserTask;
import org.kie.kogito.UserTaskParam.ParamType;
import org.kie.kogito.UserTaskParam;

@UserTask(taskName = "ManualAssignment", processName = "serviceDesk")
public class ServiceDesk_11_TaskInput {

    private String _id;

    private String _name;

    public void setId(String id) {
        this._id = id;
    }

    public String getId() {
        return this._id;
    }

    public void setName(String name) {
        this._name = name;
    }

    public String getName() {
        return this._name;
    }

    public static ServiceDesk_11_TaskInput from(org.kie.kogito.process.WorkItem workItem) {
        ServiceDesk_11_TaskInput item = new ServiceDesk_11_TaskInput();
        item._id = workItem.getId();
        item._name = workItem.getName();
        Map<String, Object> params = workItem.getParameters();
        item.supportCase = (org.kie.flexible.kogito.example.model.SupportCase) params.get("supportCase");
        return item;
    }

    @UserTaskParam(value = ParamType.INPUT)
    private org.kie.flexible.kogito.example.model.SupportCase supportCase;

    public org.kie.flexible.kogito.example.model.SupportCase getSupportCase() {
        return supportCase;
    }

    public void setSupportCase(org.kie.flexible.kogito.example.model.SupportCase supportCase) {
        this.supportCase = supportCase;
    }
}
// Task input model for user task 'Manual assignment' in process 'serviceDesk'

==> flexible-process-springboot-1.7.0.Final-sources.jar: org/kie/flexible/kogito/example/ServiceDesk_11_TaskInput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.flexible.kogito.example;

import java.util.Map;
import org.kie.kogito.UserTask;
import org.kie.kogito.UserTaskParam.ParamType;
import org.kie.kogito.UserTaskParam;

@UserTask(taskName = "ManualAssignment", processName = "serviceDesk")
public class ServiceDesk_11_TaskInput {

    public static ServiceDesk_11_TaskInput fromMap(Map<String, Object> params) {
        ServiceDesk_11_TaskInput item = new ServiceDesk_11_TaskInput();
        item.supportCase = (org.kie.flexible.kogito.example.model.SupportCase) params.get("supportCase");
        return item;
    }

    @UserTaskParam(value = ParamType.INPUT)
    private org.kie.flexible.kogito.example.model.SupportCase supportCase;

    public org.kie.flexible.kogito.example.model.SupportCase getSupportCase() {
        return supportCase;
    }

    public void setSupportCase(org.kie.flexible.kogito.example.model.SupportCase supportCase) {
        this.supportCase = supportCase;
    }
}
// Task input for user task 'Manual assignment' in process 'serviceDesk'
